SoziGen - describe your slides in python
========================================

This project's purpose is to automate buildoing of the hierachical slideshows. It is useful
to show monitoring graphs on large TV displays and projectors.

With SoziGen, you describe graphs layout in python and it generates SVG file to be
opened in any modern web browser.

Example
-------

http://svetlyak40wt.github.com/sozigen/example.svg

Contributors
------------

This project uses unmodified javascript from [Sozi][] projects, written by Guillaume Savaton and Co.
Python generator was written by Alexander Artemenko.

[sozi]: http://sozi.baierouge.fr/wiki/Sozi
